@@ -174,7 +174,7 @@ collapse.ggtree <- function(x=NULL, node, mode = "none", clade_name = NULL, ...)
 
     if (mode != "none") {
         tree_view <- tree_view +
-            geom_polygon(mapping = aes_(x = ~x, y = ~y),
+            geom_polygon(mapping = aes(x = !!sym("x"), y = !!sym("y")),
                          data = triangle, inherit.aes = FALSE, ...)
     }
 
